==> git-delta_0.16.5.orig.tar.gz: delta-0.16.5/manual/src/SUMMARY.md <==
# Summary

- [Introduction](./introduction.md)
- [Get started](./get-started.md)
- [Features](./features.md)
- [Installation](./installation.md)
- [Configuration](./configuration.md)
- [Environment variables](./environment-variables.md)
- [How delta works](./how-delta-works.md)
- [Usage](./usage.md)
  - [Choosing colors (styles)](./choosing-colors-styles.md)
  - [Line numbers](./line-numbers.md)
  - [Side-by-side view](./side-by-side-view.md)
  - [Grep](./grep.md)
  - ["Features": named groups of settings](./features-named-groups-of-settings.md)
  - [Custom themes](./custom-themes.md)
  - [diff-highlight and diff-so-fancy emulation](./diff-highlight-and-diff-so-fancy-emulation.md)
  - [--color-moved support](./color-moved-support.md)
  - [Navigation keybindings for large diffs](./navigation-keybindings-for-large-diffs.md)
  - [Merge conflicts](./merge-conflicts.md)
  - [Git blame](./git-blame.md)
  - [Supported languages and themes](./supported-languages-and-themes.md)
- [Tips & tricks](./tips-and-tricks.md)
  - [24 bit color (truecolor)](./tips-and-tricks/24-bit-color-truecolor.md)
  - [Mouse scrolling](./tips-and-tricks/mouse-scrolling.md)
  - [Save output with colors to HTML/PDF etc](./tips-and-tricks/export-to-html.md)
  - [Using Delta on Windows](./tips-and-tricks/using-delta-on-windows.md)
  - [Using Delta with GNU Screen](./tips-and-tricks/using-delta-with-gnu-screen.md)
  - [Using Delta with Magit](./tips-and-tricks/using-delta-with-magit.md)
  - [Using Delta with tmux](./tips-and-tricks/using-delta-with-tmux.md)
  - [Using Delta with VSCode](./tips-and-tricks/using-delta-with-vscode.md)
- [Comparisons with other tools](./comparisons-with-other-tools.md)
- [Build delta from source](./build-delta-from-source.md)
- [Related projects](./related-projects.md)
- [Full --help output](./full---help-output.md)
- [Delta configs used in screenshots](./delta-configs-used-in-screenshots.md)

==> git-delta_0.18.2.orig.tar.gz: delta-0.18.2/manual/src/SUMMARY.md <==
# Summary

- [Introduction](./introduction.md)
- [Get started](./get-started.md)
- [Features](./features.md)
- [Installation](./installation.md)
- [Configuration](./configuration.md)
- [Environment variables](./environment-variables.md)
- [How delta works](./how-delta-works.md)
- [Usage](./usage.md)
  - [Choosing colors (styles)](./choosing-colors-styles.md)
  - [Line numbers](./line-numbers.md)
  - [Hyperlinks](./hyperlinks.md)
  - [Side-by-side view](./side-by-side-view.md)
  - [Grep](./grep.md)
  - ["Features": named groups of settings](./features-named-groups-of-settings.md)
  - [Custom themes](./custom-themes.md)
  - [diff-highlight and diff-so-fancy emulation](./diff-highlight-and-diff-so-fancy-emulation.md)
  - [--color-moved support](./color-moved-support.md)
  - [Navigation keybindings for large diffs](./navigation-keybindings-for-large-diffs.md)
  - [Merge conflicts](./merge-conflicts.md)
  - [Git blame](./git-blame.md)
  - [Supported languages and themes](./supported-languages-and-themes.md)
- [Tips & tricks](./tips-and-tricks.md)
  - [Toggling side-by-side and other delta features](./tips-and-tricks/toggling-delta-features.md)
  - [24 bit color (truecolor)](./tips-and-tricks/24-bit-color-truecolor.md)
  - [Mouse scrolling](./tips-and-tricks/mouse-scrolling.md)
  - [Save output with colors to HTML/PDF etc](./tips-and-tricks/export-to-html.md)
  - [Using Delta on Windows](./tips-and-tricks/using-delta-on-windows.md)
  - [Using Delta with GNU Screen](./tips-and-tricks/using-delta-with-gnu-screen.md)
  - [Using Delta with Magit](./tips-and-tricks/using-delta-with-magit.md)
  - [Using Delta with tmux](./tips-and-tricks/using-delta-with-tmux.md)
  - [Using Delta with VSCode](./tips-and-tricks/using-delta-with-vscode.md)
  - [Generating shell completion files](./tips-and-tricks/shell-completion.md)
- [Comparisons with other tools](./comparisons-with-other-tools.md)
- [Build delta from source](./build-delta-from-source.md)
- [Related projects](./related-projects.md)
- [Full --help output](./full---help-output.md)
- [Delta configs used in screenshots](./delta-configs-used-in-screenshots.md)
